gosoap

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 30, 2022 License: MIT Imports: 1 Imported by: 0

README

gosoap

GoDoc

Generates all the necessary soap code blocks, including a proxy from a given wsdl file.

Install
  • Download binary release
  • Download and build locally: go get github.com/go-aegian/gosoap/...
  • Install from go: go install github.com/go-aegian/gosoap/...
  • Uninstall: go clean -i -n github.com/go-aegian/gosoap
Goals
  • Generate go code for the wsdl definition
  • Support only Document/Literal wrapped services, which are WS-I compliant
  • Support:
    • WSDL 1.1
    • XML Schema 1.0
    • SOAP 1.1
  • Resolve external XML Schemas
  • Support external and local WSDL
Caveats
  • Please keep in mind that the generated code is just a reflection of what the WSDL is like. If your WSDL has duplicated type definitions, your Go code is going to have the same and may not compile.
Usage
Usage: gosoap [options] services.wsdl
  -o string
        File where the generated code will be saved (default "services-proxy.go")
  -p string
        Package under which code will be generated (default "servicesProxy")
  -i    Skips TLS Verification
  -v    Shows gosoap version

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(file, pkg string, ignoreTLS bool, exportAllTypes bool) (*builder.Builder, error)

New creates the builder.

Types

This section is empty.

Directories

Path Synopsis
xsd
cmd
gosoap command
tests

Jump to